@@ -17,6 +17,7 @@ const BASE_UNITS: &[UnitTuple] = &[
     ("ampere", "amperes", "l@!", ""),
     ("mole", "moles", "l@!", ""),
     ("candela", "candelas", "l@!", ""),
+    ("neper", "nepers", "l@!", ""),
 ];
 
 const BASE_UNIT_ABBREVIATIONS: &[UnitTuple] = &[
@@ -31,6 +32,7 @@ const BASE_UNIT_ABBREVIATIONS: &[UnitTuple] = &[
     ("A", "", "s@ampere", ""),
     ("mol", "", "s@mole", ""),
     ("cd", "", "s@candela", ""),
+    ("Np", "", "s@neper", ""),
 ];
 
 // some temperature scales have special support for conversions
@@ -381,6 +383,9 @@ const RATIOS: &[UnitTuple] = &[
     ("\u{2030}", "", "0.001", ""), // per mille
     ("percent", "", "0.01", ""),
     ("%", "", "percent", ""),
+    ("bel", "bels", "0.5 * ln(10) neper", ""),
+    ("decibel", "decibels", "1/10 bel", ""),
+    ("dB", "", "decibel", ""),
     ("mill", "mills", "0.001", ""),
     ("ppm", "", "1e-6", ""),
     ("parts_per_million", "", "ppm", ""),
@@ -432,6 +437,10 @@ const COMMON_PHYSICAL_UNITS: &[UnitTuple] = &[
     ),
     ("btu", "", "british_thermal_unit", ""),
     ("Wh", "", "s@W hour", ""),
+    ("atmosphere", "atmospheres", "l@101325 Pa", ""),
+    ("atm", "", "s@atmosphere", ""),
+    ("mmHg", "", "l@1/760 atm", "millimeter of mercury"),
+    ("inHg", "", "l@25.4 mmHg", "inch of mercury"),
     ("bar", "", "l@1e5 Pa", "about 1 atmosphere"),
     ("diopter", "", "l@/m", "reciprocal of focal length"),
     ("sqm", "", "=m^2", ""),
@@ -442,6 +451,7 @@ const COMMON_PHYSICAL_UNITS: &[UnitTuple] = &[
 
 const IMPERIAL_UNITS: &[UnitTuple] = &[
     ("inch", "inches", "2.54 cm", ""),
+    ("mil", "mils", "1/1000 inch", ""),
     ("\u{2019}", "", "foot", ""), // unicode single quote
     ("\u{201d}", "", "inch", ""), // unicode double quote
     ("'", "", "foot", ""),
