@@ -5289,3 +5289,59 @@ fn day_of_week_type_name() {
 fn phi() {
     test_eval("phi", "approx. 1.6180339886");
 }
+
+#[test]
+fn five_dollars() {
+    test_eval("$5", "$5");
+}
+
+#[test]
+fn dollar_prefix() {
+    test_eval_simple("$200/3 to 2dp", "approx. $66.66");
+}
+
+#[test]
+fn dollar_multiplication() {
+    test_eval("$3 * 7", "$21");
+}
+
+#[test]
+#[ignore]
+fn dollar_multiplication_reverse() {
+    test_eval("7 * $3", "$21");
+}
+
+#[test]
+fn gbp_symbol() {
+    test_eval("£5 + £3", "£8");
+}
+
+#[test]
+fn two_statements() {
+    test_eval("2; 4", "4");
+}
+
+#[test]
+fn five_statements() {
+    test_eval("2; 4; 8kg; c:2c; a = 2", "2");
+}
+
+#[test]
+fn variable_assignment() {
+    test_eval("a = b = 2; b", "2");
+}
+
+#[test]
+fn overwrite_variable() {
+    test_eval("a = 3; a = a + 4a; a", "15");
+}
+
+#[test]
+fn multiple_variables() {
+    test_eval("a = 3; b = 2a; c = a * b; c + a", "21");
+}
+
+#[test]
+fn mixed_frac() {
+    test_eval_simple("4/3 to mixed_frac", "1 1/3");
+}
